{% verbatim %}{{#multiple}}
<div data-role="footer">
  {{#previous}}
  <a href="{{previous}}" data-icon="carat-l" data-iconpos="left"
    data-direction="reverse" class="ui-btn-left">
    {{^previous_is_local}}
    Prev {{per_page}}
    {{/previous_is_local}}
    {{#previous_is_local}}
    Local Cache
    {{/previous_is_local}}
  </a>
  {{/previous}}
  <h3>
    {{^current_is_local}}Page {{page}} of {{pages}}{{/current_is_local}}
    {{#current_is_local}}&nbsp;{{/current_is_local}}
  </h3>
  {{#next}}
  <a href="{{next}}" data-icon="carat-r" data-iconpos="right"
     class="ui-btn-right">
    {{^current_is_local}}
    Next {{per_page}}
    {{/current_is_local}}
    {{#current_is_local}}
    All Data
    {{/current_is_local}}
  </a>
  {{/next}}
</div>
{{/multiple}}{% endverbatim %}
