<!DOCTYPE html>

<!--
NOTE: This template is only meant to provide a bootstrap to help new projects
get up and running with wq.  Please throw this out and replace it with your own
interesting and unique designs, styles and layouts.  The sky is the limit!

To make your application work offline using the old "application cache" standard,
uncomment the manifest attribute below.  This is disabled by default because it
isn't always needed and it makes debugging more tricky.
See https://github.com/wq/wq.app/issues/63
-->
<html><!-- manifest="{{ project_name }}.appcache" -->
  <head>
    <title>{{ project_name }} Project</title>
    <meta name="apple-mobile-web-app-capable" content="yes">
    <link rel="manifest" href="manifest.json">
    {% templatetag openvariable %}>head{% templatetag closevariable %}
  </head>
  <body>
    <div data-role="page" class="ui-page">
      <div data-role="header">
        <h1>{{ project_name }} Project</h1>
      </div>
      <div role="main" class="ui-content">
        <p>Hello, world!</p>
        <ul data-role="listview">
          <!-- Note: in many cases, you will want to replace this with a
          hardcoded list of links (rather than the default pages list) -->
          {% verbatim %}{{#pages}}
          <li><a href="{{rt}}/{{url}}{{#list}}/{{/list}}">{{name}} {{#list}}list{{/list}}</a></li>
          {{/pages}}{% endverbatim %}
        </ul>
      </div>
      <p class="footer">
        {{ project_name }} v{% templatetag openvariable %}version{% templatetag closevariable %}
        &bull;
        Powered by <a href="https://wq.io/">wq</a>
      </p>
    </div>
  </body>
</html>
